document.addEventListener('DOMContentLoaded', () => {
  const container = document.getElementById('letter-container');
  const letters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.split('');
  
  class FallingLetter {
    constructor(letter) {
      this.element = document.createElement('div');
      this.element.className = 'letter';
      this.element.textContent = letter;
      this.x = Math.random() * (container.offsetWidth - 30);
      this.y = -50;
      this.speed = 1 + Math.random() * 2;
      this.rotation = Math.random() * 360;
      this.rotationSpeed = (Math.random() - 0.5) * 4;
      
      this.element.style.left = `${this.x}px`;
      this.element.style.top = `${this.y}px`;
      container.appendChild(this.element);
      
      this.element.addEventListener('click', () => this.reset());
    }
    
    update() {
      this.y += this.speed;
      this.rotation += this.rotationSpeed;
      
      if (this.y > container.offsetHeight) {
        this.reset();
      }
      
      this.element.style.transform = `translateY(${this.y}px) rotate(${this.rotation}deg)`;
    }
    
    reset() {
      this.y = -50;
      this.x = Math.random() * (container.offsetWidth - 30);
      this.rotation = Math.random() * 360;
      this.speed = 1 + Math.random() * 2;
      this.element.style.left = `${this.x}px`;
    }
  }
  
  const fallingLetters = letters.map(letter => new FallingLetter(letter));
  
  function animate() {
    fallingLetters.forEach(letter => letter.update());
    requestAnimationFrame(animate);
  }
  
  animate();
  
  window.addEventListener('resize', () => {
    fallingLetters.forEach(letter => {
      if (letter.x > container.offsetWidth - 30) {
        letter.x = Math.random() * (container.offsetWidth - 30);
        letter.element.style.left = `${letter.x}px`;
      }
    });
  });
});